@@ -1,12 +1,10 @@
 import ast
 import json
 import logging
-import platform
 from threading import Thread
 from time import sleep
 import socketio
 from aiortc import RTCPeerConnection, RTCRtpSender, RTCConfiguration, RTCIceServer, RTCSessionDescription
-from aiortc.contrib.media import MediaPlayer, MediaRelay
 
 try:
     import picamera
