@@ -4,7 +4,7 @@ import logging
 
 import socketio
 from aiortc import MediaStreamTrack, RTCPeerConnection, RTCIceServer, RTCConfiguration
-from aiortc.contrib.media import MediaRelay
+from aiortc.contrib.media import MediaRelay, MediaBlackhole
 from aiortc.rtcrtpreceiver import RemoteStreamTrack
 
 relay = MediaRelay()
@@ -81,10 +81,12 @@ class GSPeerConnectionWatcher:
                         await self.ontrack(self.gsdbs, track, self.target)
                     if self.onframe is not None:
                         self.logger.info("on track received. Onframe started")
-                        self.peerConnections.addTrack(
-                            VideoTransformTrack(
-                                relay.subscribe(track), self.gsdbs, self.target, self.onframe)
-                        )
+                        blackHole = MediaBlackhole()
+                        mediaTrack = VideoTransformTrack(
+                            relay.subscribe(track), self.gsdbs, self.target, self.onframe)
+                        blackHole.addTrack(mediaTrack)
+                        await blackHole.start()
+
 
                 @track.on("ended")
                 async def on_ended():
